@@ -67,4 +67,20 @@ def getUniqueTokenFromTransactions(connection, schema, public_address:str=None,
 
     allResults = [*resultSend, *resultRecv]
 
-    return allResults
\ No newline at end of file
+    return allResults
+
+def getUniqueAddress(connection, schema,chain_id:int=None):
+    
+    queryStr = "select distinct(public_address) \
+        FROM {}.dwh_address_account"
+
+    params = []
+
+    if chain_id:
+        queryStr = queryStr + " AND chain_id=%s"
+        params.append(chain_id)
+
+    query = sql.SQL(queryStr).format(sql.Identifier(schema))
+
+    result = herokuDbAccess.fetchDataInDatabase(query, params, connection)    
+    return result
\ No newline at end of file
